[![PyPI version](https://badge.fury.io/py/jinjath.svg)](https://badge.fury.io/py/jinjath)

Jinja Template Helpers
======================
Helper classes for working with [Jinja2][jinja2] templates, especially when the template source is provided by the user.

[jinja2]: <http://jinja.pocoo.org/>
